@@ -29,7 +29,7 @@ temperatures_folders = read.read_post_proc(input_file)[14]
 NAC = read.read_post_proc(input_file)[15]
 appendix = read.read_post_proc(input_file)[16]
 
-K = read.read_FC(file_forces)
+K = np.loadtxt(file_forces)
 BORN_file = 'BORN'
 prefix = ''
 
@@ -214,10 +214,10 @@ if(plot_type==4):
     # SCell_fc, R0_fc, R_fc = util.get_R_FC(N1, N2, N3, 4,4,4,tot_atoms_uc, Suc, SCell) 
 # =============================================================================
     freq_DOS, DOS, DOS_renorm = np.arange(0,25,0.01), np.zeros(len(np.arange(0,25,0.01))), np.zeros(len(np.arange(0,25,0.01)))
-    kpoints_scal, kpoints = util.get_kgrid(interp,interp,interp, Hk)
+    Nqs, kpoints_scal, kpoints = util.get_kgrid(interp,interp,interp, Hk)
     N1N2N3_k = interp*interp*interp
-    irr_ks, irr_ks_sc, weights, permutation_types = util.get_irr_ks(kpoints, kpoints_scal)    
-    for i in range(len(irr_ks)):
+    Nqs_irr, irr_ks, irr_ks_sc, weights, permutation_types = util.get_irr_ks(kpoints, kpoints_scal)    
+    for i in range(Nqs_irr):
         k = irr_ks[i]
         weight = weights[i]
         print('\t processing DOS k-point:', i, irr_ks_sc[i])
@@ -302,10 +302,10 @@ if(plot_type==40):
             
 # =============================================================================
     freq_DOS, DOS = np.arange(0,25,0.01), np.zeros(len(np.arange(0,25,0.01)))
-    kpoints_scal, kpoints = util.get_kgrid(interp, interp, interp, Hk)
+    Nqs, kpoints_scal, kpoints = util.get_kgrid(interp, interp, interp, Hk)
     N1N2N3_k = interp*interp*interp
-    irr_ks, irr_ks_sc, weights, permutation_types = util.get_irr_ks(kpoints, kpoints_scal)
-    for i in range(len(irr_ks)):
+    Nqs_irr, irr_ks, irr_ks_sc, weights, permutation_types = util.get_irr_ks(kpoints, kpoints_scal)
+    for i in range(Nqs_irr):
         k = irr_ks[i]
         weight = weights[i]
         print('\t processing DOS k-point:', i, irr_ks_sc[i])
